@@ -2,22 +2,22 @@
 base class for python applications with a graphical user interface
 ==================================================================
 
-The abstract base class :class:`MainAppBase` provided by this ae namespace portion allows the integration of any Python
+the abstract base class :class:`MainAppBase` provided by this ae namespace portion allows the integration of any Python
 GUI framework into the ae namespace.
 
-On overview about the available GUI-framework-specific ae namespace portion implementations can be found in the
+on overview about the available GUI-framework-specific ae namespace portion implementations can be found in the
 documentation of the ae namespace portion :mod:`ae.lisz_app_data`.
 
 
 extended console application environment
 ----------------------------------------
 
-The abstract base class :class:`MainAppBase` inherits directly from the ae namespace class
-:class:`ae console application environment class <ae.console.ConsoleApp>`. The so inherited helper methods are useful
+the abstract base class :class:`MainAppBase` inherits directly from the ae namespace class
+:class:`ae console application environment class <ae.console.ConsoleApp>`. the so inherited helper methods are useful
 to log, configure and control the run-time of your GUI app via command line arguments.
 
 .. hint::
-    Please see the documentation of :ref:`config-options` and :ref:`config-files` in the :mod:`ae.console` namespace
+    please see the documentation of :ref:`config-options` and :ref:`config-files` in the :mod:`ae.console` namespace
     portion/module for more detailed information.
 
 :class:`MainAppBase` adds on top of the :class:`~ae.console.ConsoleApp` the concepts of :ref:`application status` and
@@ -27,11 +27,11 @@ to log, configure and control the run-time of your GUI app via command line argu
 application events
 ------------------
 
-The events described in this section are fired on application startup and shutdown. Additional events get fired e.g. in
+the events described in this section are fired on application startup and shutdown. additional events get fired e.g. in
 relation to the app states (documented further down in the section :ref:`app state events`) or on start or stop of an
 :ref:`app tour <app tour start and stop events>`.
 
-The following application events are fired exactly one time at startup in the following order:
+the following application events are fired exactly one time at startup in the following order:
 
 * `on_app_init`: fired **after** :class:`ConsoleApp` app instance got initialized (detected config files)
   and **before** the image and sound resources and app states get loaded and the GUI framework app class instance gets
@@ -44,15 +44,15 @@ The following application events are fired exactly one time at startup in the fo
   loop of the used GUI framework gets started.
 
 .. note::
-    The `on_app_build` application event has to be fired by the used GUI framework.
+    the `on_app_build` application event has to be fired by the used GUI framework.
 
 .. hint::
-    Depending on the used gui framework there can be more app start events. E.g. the :mod:`ae.kivy_app` module fires the
-    events `on_app_built` and `on_app_started` (all of them fired after `on_app_run` and `on_app_build`). See also
+    depending on the used gui framework there can be more app start events. e.g. the :mod:`ae.kivy_app` module fires the
+    events `on_app_built` and `on_app_started` (all of them fired after `on_app_run` and `on_app_build`). see also
     :ref:`kivy application events`.
 
 
-When an application gets stopped then the following events get fired in the following order:
+when an application gets stopped then the following events get fired in the following order:
 
 * `on_app_stop`: fired **after** the call of the method :meth:`~MainAppBase.stop_app` and **before** the framework win
   will be closed.
@@ -62,25 +62,25 @@ When an application gets stopped then the following events get fired in the foll
   method will be called.
 
 .. note::
-    The `on_app_stop` and `on_app_exit` events will only be fired if the app is explicitly calling the
+    the `on_app_stop` and `on_app_exit` events will only be fired if the app is explicitly calling the
     :meth:`~MainAppBase.stop_app` method.
 
 .. hint::
-    Depending on the used gui framework there can be more events. E.g. the :mod:`ae.kivy_app` module fires the event
+    depending on the used gui framework there can be more events. e.g. the :mod:`ae.kivy_app` module fires the event
     `on_app_stopped` (before `on_app_stop` respectively `on_app_quit`).
 
 
 application status
 ------------------
 
-Any application- and user-specific configurations like e.g. the last window position/size, the app theme/font/language
+any application- and user-specific configurations like e.g. the last window position/size, the app theme/font/language
 or the last selected flow within your app, could be included in the application status.
 
-This namespace portion introduces the section `aeAppState` in the app :ref:`config-files`, where any status values can
+this namespace portion introduces the section `aeAppState` in the app :ref:`config-files`, where any status values can
 be stored persistently to be recovered on the next startup of your application.
 
 .. hint::
-    The section name `aeAppState` is declared by the :data:`APP_STATE_SECTION_NAME` constant. If you need to access this
+    the section name `aeAppState` is declared by the :data:`APP_STATE_SECTION_NAME` constant. if you need to access this
     config section directly then please use this constant instead of the hardcoded section name.
 
 
@@ -89,7 +89,7 @@ be stored persistently to be recovered on the next startup of your application.
 app state variables
 ^^^^^^^^^^^^^^^^^^^
 
-This module is providing/pre-defining the following application state variables:
+this module is providing/pre-defining the following application state variables:
 
     * :attr:`~MainAppBase.app_state_version`
     * :attr:`~MainAppBase.flow_id`
@@ -105,30 +105,30 @@ This module is providing/pre-defining the following application state variables:
     * :attr:`~MainAppBase.vibration_volume`
     * :attr:`~MainAppBase.win_rectangle`
 
-Which app state variables are finally used by your app project is (fully data-driven) depending on the app state
-:ref:`config-variables` detected in all the :ref:`config-files` that are found/available at run-time of your app. The
+which app state variables are finally used by your app project is (fully data-driven) depending on the app state
+:ref:`config-variables` detected in all the :ref:`config-files` that are found/available at run-time of your app. the
 names of all the available application state variables can be determined with the main app helper method
 :meth:`~MainAppBase.app_state_keys`.
 
-If your application is e.g. supporting a user-defined font size, using the provided/pre-defined app state variable
+if your application is e.g. supporting a user-defined font size, using the provided/pre-defined app state variable
 :attr:`~MainAppBase.font_size`, then it has to call the method :meth:`change_app_state` with the argument of
 :paramref:`~MainAppBase.change_app_state.app_state_name` set to `font_size` every time when the user has changed the
 font size of your app.
 
 .. hint::
-    The two built-in app state variables are :attr:`~MainAppBase.flow_id` and :attr:`~MainAppBase.flow_path` will be
+    the two built-in app state variables are :attr:`~MainAppBase.flow_id` and :attr:`~MainAppBase.flow_path` will be
     explained detailed in the next section.
 
-The :meth:`~MainBaseApp.load_app_states` method is called on instantiation from the implemented main app class to
+the :meth:`~MainBaseApp.load_app_states` method is called on instantiation from the implemented main app class to
 load the values of all app state variables from the :ref:`config-files`, and is then calling
 :meth:~MainAppBase.setup_app_states` for pass them into their corresponding instance attributes.
 
-Use the main app instance attribute to read/get the actual value of a single app state variable. The actual values of
+use the main app instance attribute to read/get the actual value of a single app state variable. the actual values of
 all app state variables as a dict is determining the method :meth:`~MainBaseApp.retrieve_app_states`, and can be saved
 into the :ref:`config-files` for the next app run via the method :meth:`~MainBaseApp.save_app_states` - this could be
 done e.g. after the app state has changed or at least on quiting the application.
 
-Changed app state values have to be saved always by calling the method :meth:`~MainBaseApp.change_app_state` (which
+changed app state values have to be saved always by calling the method :meth:`~MainBaseApp.change_app_state` (which
 ensures (1) the propagation to any duplicated (observable/bound) framework property and (2) the event notification to
 related the main app instance method).
 
@@ -138,7 +138,7 @@ related the main app instance method).
 app state constants
 ^^^^^^^^^^^^^^^^^^^
 
-This module is also providing some pre-defined constants that can be optionally used in your application in relation to
+this module is also providing some pre-defined constants that can be optionally used in your application in relation to
 the app states data store and for the app state config variables :attr:`~MainAppBase.app_state_version`,
 :attr:`~MainAppBase.font_size` and :attr:`~MainAppBase.light_theme`:
 
@@ -155,27 +155,27 @@ the app states data store and for the app state config variables :attr:`~MainApp
 app state events
 ^^^^^^^^^^^^^^^^
 
-There are three types of notification events get fired in relation to the app state variables, using the method names:
+there are three types of notification events get fired in relation to the app state variables, using the method names:
 
 * `on_<app_state_name>`: fired if the user of the app is changing the value of an app state variable.
 * `on_<app_state_name>_save`: fired if a app state gets saved to the config file.
 * `on_app_state_version_upgrade`: fired if the user upgrades an previously installed app to a higher version.
 
-The method name of the app state change notification event consists of the prefix ``on_`` followed by the variable name
-of the app state. So e.g. on a change of the `font_size` app state the notification event `on_font_size` will be
-fired/called (if exists as a method of the main app instance). These events don't provide any event arguments.
+the method name of the app state change notification event consists of the prefix ``on_`` followed by the variable name
+of the app state. so e.g. on a change of the `font_size` app state the notification event `on_font_size` will be
+fired/called (if exists as a method of the main app instance). these events don't provide any event arguments.
 
-The second event gets fired for each app state value just after the app states getting retrieved from the app class
-instance and before they get stored into the main config file. The method name of this event includes also the name of
+the second event gets fired for each app state value just after the app states getting retrieved from the app class
+instance and before they get stored into the main config file. the method name of this event includes also the name of
 the app state with the suffix `_save`, so e.g. for the app state `flow_id` the event method name will result in
-:meth:`on_app_state_flow_id_save`. This event is providing one event argument with the value of the app state. If the
+:meth:`on_app_state_flow_id_save`. this event is providing one event argument with the value of the app state. if the
 event method returns a value that is not `None` then this value will be stored/saved.
 
-The third event gets fired on app startup when the app got upgraded to a higher version of the app state variable
-APP_STATE_VERSION_VAR_NAME (`app_state_version`). It will be called providing the version number for each version to
+the third event gets fired on app startup when the app got upgraded to a higher version of the app state variable
+APP_STATE_VERSION_VAR_NAME (`app_state_version`). it will be called providing the version number for each version to
 upgrade, starting with the version of the previously installed main config file, until the upgrade version of the main
-config file get reached. So if e.g. the previously installed app state version was 3 and the new version number is
-6 then this event will be fired 3 times with the argument 3, 4 and 5. It can be used e.g. to change or add app state
+config file get reached. so if e.g. the previously installed app state version was 3 and the new version number is
+6 then this event will be fired 3 times with the argument 3, 4 and 5. it can be used e.g. to change or add app state
 variables or to adapt the app environment.
 
 
@@ -186,18 +186,18 @@ to control the current state and application/work flow (or context) of your appl
 next app start, :class:`MainBaseApp` provides two :ref:`app-state-variables`: :attr:`~MainAppBase.flow_id` to store the
 currently working flow and :attr:`~MainAppBase.flow_path` to store the history of nested flows.
 
-A application flow is represented by an id string that defines three things: (1) the action to enter into the flow, (2)
+an application flow is represented by an id string that defines three things: (1) the action to enter into the flow, (2)
 the data or object that gets currently worked on and (3) an optional key string that is identifying/indexing a widget or
 data item of your application context/flow.
 
 .. note::
-    Never concatenate a flow id string manually, use the :func:`id_of_flow` function instead.
+    never concatenate a flow id string manually, use the :func:`id_of_flow` function instead.
 
-The flow id is initially an empty string. As soon as the user is starting a new work flow or the current selection your
+the flow id is initially an empty string. as soon as the user is starting a new work flow or the current selection your
 application should call the method :meth:`~MainBaseApp.change_flow` passing the flow id string into the
 :paramref:`~MainAppBase.change_flow.new_flow_id` argument to change the app flow.
 
-For more complex applications you can specify a path of nested flows. This flow path gets represented by the app state
+for more complex applications you can specify a path of nested flows. this flow path gets represented by the app state
 variable :attr:`~MainAppBase.flow_path`, which is a list of flow id strings.
 
 to enter into a deeper/nested flow you simply call :meth:`~MainBaseApp.change_flow` with one of the actions defined
@@ -210,35 +210,35 @@ defined in :data:`ACTIONS_REDUCING_FLOW_PATH`.
 application flow change events
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
-The flow actions specified by :data:`ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION` don't need a flow change confirmation
+the flow actions specified by :data:`ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION` don't need a flow change confirmation
 event handler:
 
 * `'enter'` or `'leave'` extend/reduce the flow path.
 * `'focus'` pass/change the input focus.
 * `'suggest'` for autocompletion or other suggestions.
 
-All other flow actions need to confirmed to be changed by :meth:`~MainAppBase.change_flow`, either by a custom flow
+all other flow actions need to confirmed to be changed by :meth:`~MainAppBase.change_flow`, either by a custom flow
 change confirmation method/event-handler or by declaring a popup class that has the same name returned by
 :func:`flow_popup_class_name` if called with the new flow id.
 
-The name of the flow change confirmation method that gets fired when the app want to change the flow (via the method
+the name of the flow change confirmation method that gets fired when the app want to change the flow (via the method
 :meth:`~MainAppBase.change_flow`) depends on the new flow id and gets determined by the function
 :func:`flow_change_confirmation_event_name`.
 
-If the flow-specific change confirmation event handler does not exist or returns in a boolean `False` or `None` then
-:meth:`~MainAppBase.on_flow_change` will be called. And if this call also returns `False` then the action of the new
-flow id will be searched within :data:`ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION` and if not found then the flow change
-will be rejected and :meth:`~MainAppBase.change_flow` returns `False`.
+if the flow-specific change confirmation event handler does not exist or returns in a boolean `False` or `None` then
+:meth:`~MainAppBase.on_flow_change` will be called. if this call also returns `False` then the action of the new flow id
+will be searched within :data:`ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION` and if not found then the flow change will be
+rejected and :meth:`~MainAppBase.change_flow` returns `False`.
 
-If in contrary either the flow change confirmation event handler exists and does return `True` or
+if in contrary either the flow change confirmation event handler exists and does return `True` or
 :meth:`~MainAppBase.on_flow_change` returns True or the flow action of the new flow id is in
 :data:`ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION` then the flow id and path will be changed accordingly.
 
-After the flow id/path change confirmation the method :meth:`~MainAppBase.change_flow` checks if the optional
+after the flow id/path change confirmation the method :meth:`~MainAppBase.change_flow` checks if the optional
 event_kwargs key `changed_event_name` got specified and if yes then it calls this method.
 
-Finally if a confirmed flow change results in a `'focus'` flow action then the event `on_flow_widget_focused` will be
-fired. This event can be used by the GUI framework to set the focus to the widget associated with the new focus flow id.
+finally if a confirmed flow change results in a `'focus'` flow action then the event `on_flow_widget_focused` will be
+fired. this event can be used by the GUI framework to set the focus to the widget associated with the new focus flow id.
 
 
 key press events
@@ -248,7 +248,7 @@ to provide key press events to the applications that will use the new GUI framew
 events of the framework, convert/normalize them and then call the :meth:`~MainAppBase.key_press_from_framework` with the
 normalized modifiers and key args.
 
-The :paramref:`~MainAppBase.key_press_from_framework.modifiers` arg is a string that can contain several of the
+the :paramref:`~MainAppBase.key_press_from_framework.modifiers` arg is a string that can contain several of the
 following sub-strings, always in the alphabetic order (like listed below):
 
 * Alt
@@ -256,7 +256,7 @@ following sub-strings, always in the alphabetic order (like listed below):
 * Meta
 * Shift
 
-The :paramref:`~MainAppBase.key_press_from_framework.key` arg is a string that is specifying the last pressed key. If
+the :paramref:`~MainAppBase.key_press_from_framework.key` arg is a string that is specifying the last pressed key. if
 the key is not representing not a single character but a command key, then `key` will be one of the following strings:
 
 * escape
@@ -274,18 +274,18 @@ the key is not representing not a single character but a command key, then `key`
 * pgup
 * pgdown
 
-On call of :meth:`~MainAppBase.key_press_from_framework` this method will try to dispatch the key press event to your
-application. First it will check the app instance if it has declared a method with the name
+on call of :meth:`~MainAppBase.key_press_from_framework` this method will try to dispatch the key press event to your
+application. first it will check the app instance if it has declared a method with the name
 `on_key_press_of_<modifiers>_<key>` and if so it will call this method.
 
-If this method does return False (or any other value resulting in False) then method
+if this method does return False (or any other value resulting in False) then method
 :meth:`~MainAppBase.key_press_from_framework` will check for a method with the same name in lower-case and if exits it
 will call this method.
 
-If also the second method does return False, then it will try to call the event method `on_key_press` of the app
+if also the second method does return False, then it will try to call the event method `on_key_press` of the app
 instance (if exists) with the modifiers and the key as arguments.
 
-If the `on_key_press` method does also return False then :meth:`~MainAppBase.key_press_from_framework` will finally pass
+if the `on_key_press` method does also return False then :meth:`~MainAppBase.key_press_from_framework` will finally pass
 the key press event to the original key press handler of the GUI framework for further processing.
 
 
@@ -295,30 +295,30 @@ integrate new gui framework
 to integrate a new Python GUI framework you have to declare a new class that inherits from :class:`MainAppBase` and
 implements at least the abstract method :meth:`~MainAppBase.init_app`.
 
-Additionally and to load the resources of the app (after the portions resources got loaded) the event `on_app_build` has
-to be fired, executing the :meth:`MainAppBase.on_app_build` method. This could be done directly from within
+additionally and to load the resources of the app (after the portions resources got loaded) the event `on_app_build` has
+to be fired, executing the :meth:`MainAppBase.on_app_build` method. this could be done directly from within
 :meth:`~MainAppBase.init_app` or by redirecting one of the events of the app instance of the GUI framework.
 
-A minimal implementation of the :meth:`~MainAppBase.init_app` method would look like the following::
+a minimal implementation of the :meth:`~MainAppBase.init_app` method would look like the following::
 
     def init_app(self):
         self.call_method('on_app_build')
         return None, None
 
-Most GUI frameworks are providing classes that need to be instantiated on application startup, like e.g. the instance of
+most GUI frameworks are providing classes that need to be instantiated on application startup, like e.g. the instance of
 the GUI framework app class, the root widget or layout of the main GUI framework window(s). to keep a reference to
 these instances within your main app class you can use the attributes :attr:`~MainAppBase.framework_app`,
 :attr:`~MainAppBase.framework_root` and :attr:`~MainAppBase.framework_win` of the class :class:`MainAppBase`.
 
-The initialization of the attributes :attr:`~MainAppBase.framework_app`, :attr:`~MainAppBase.framework_root` and
+the initialization of the attributes :attr:`~MainAppBase.framework_app`, :attr:`~MainAppBase.framework_root` and
 :attr:`~MainAppBase.framework_win` is optional and can be done e.g. within :meth:`~MainAppBase.init_app` or in the later
 called `on_app_build` application event fired by the framework app instance.
 
 .. note::
-    If :attr:`~MainAppBase.framework_win` is set to a window instance, then the window instance has to provide a `close`
+    if :attr:`~MainAppBase.framework_win` is set to a window instance, then the window instance has to provide a `close`
     method, which will be called automatically by the :meth:`~MainAppBase.stop_app`.
 
-A typical implementation of a framework-specific main app class looks like::
+a typical implementation of a framework-specific main app class looks like::
 
     from new_gui_framework import NewFrameworkApp, MainWindowClassOfNewFramework
 
@@ -330,15 +330,15 @@ A typical implementation of a framework-specific main app class looks like::
             # return callables to start/stop the event loop of the GUI framework
             return self.framework_app.start, self.framework_app.stop
 
-In this example the `on_app_build` application event gets fired either from within the `start` method of the framework
+in this example the `on_app_build` application event gets fired either from within the `start` method of the framework
 app instance or by an event provided by the GUI framework.
 
-:meth:`~MainAppBase.init_app` will be executed only once at the main app class instantiation. Only the main app instance
+:meth:`~MainAppBase.init_app` will be executed only once at the main app class instantiation. only the main app instance
 has to initialize the GUI framework to prepare the app startup and has to return at least a callable to start the event
 loop of the GUI framework.
 
 .. hint::
-    Although not recommended because of possible namespace conflicts, one could e.g. alternatively integrate the
+    although not recommended because of possible namespace conflicts, one could e.g. alternatively integrate the
     framework application class as a mixin to the main app class.
 
 to initiate the app startup the :meth:`~MainAppClass.run_app` method has to be called from the main module of your
@@ -349,21 +349,21 @@ returned by :meth:`~MainAppBase.init_app`.
 optional configuration and extension
 ------------------------------------
 
-Most of the base implementation helper methods can be overwritten by either the inheriting framework portion or directly
+most of the base implementation helper methods can be overwritten by either the inheriting framework portion or directly
 by user main app class.
 
 
 base resources for your gui app
 -------------------------------
 
-This portion is also providing base resources for commonly used images and sounds.
+this portion is also providing base resources for commonly used images and sounds.
 
-The image file resources provided by this portion are taken from:
+the image file resources provided by this portion are taken from:
 
 * `iconmonstr <https://iconmonstr.com/interface/>`_.
 
 
-The sound files provides by this portion are taken from:
+the sound files provides by this portion are taken from:
 
 * `Erokia <https://freesound.org/people/Erokia/>`_ at `freesound.org <https://freesound.org>`_.
 * `plasterbrain <https://freesound.org/people/plasterbrain/>`_ at `freesound.org <https://freesound.org>`_.
@@ -391,7 +391,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.2.79'
+__version__ = '0.2.81'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -445,7 +445,7 @@ def ensure_tap_kwargs_refs(init_kwargs: EventKwargsType, tap_widget: Any):
     :param init_kwargs:         kwargs of the widgets __init__ method.
     :param tap_widget:          reference to the tap widget.
 
-    This alternative version is only 10 % faster but much less clean than the current implementation::
+    this alternative version is only 10 % faster but much less clean than the current implementation::
 
         if 'tap_kwargs' not in init_kwargs:
             init_kwargs['tap_kwargs'] = dict()
@@ -504,7 +504,7 @@ def flow_class_name(flow_id: str, name_suffix: str) -> str:
 
     :param flow_id:         flow id.
     :param name_suffix:     class name suffix.
-    :return:                name of the class. Please note that the flow action `open` will not be added
+    :return:                name of the class. please note that the flow action `open` will not be added
                             to the returned class name.
     """
     flow, _index = flow_key_split(flow_id)
@@ -573,7 +573,7 @@ def flow_popup_class_name(flow_id: str) -> str:
     """ determine name of the Popup class for the given flow id.
 
     :param flow_id:         flow id.
-    :return:                name of the Popup class. Please note that the action `open` will not be added
+    :return:                name of the Popup class. please note that the action `open` will not be added
                             to the returned class name.
     """
     return flow_class_name(flow_id, 'Popup')
@@ -600,8 +600,8 @@ def id_of_flow(action: str, obj: str = "", key: str = "") -> str:
 def register_package_images():
     """ call from module scope of the package to register/add image/img resources path.
 
-    No parameters needed because we use here :func:`~ae.inspector.stack_var` helper function to determine the
-    the module file path via the `__file__` module variable of the caller module in the call stack. In this call
+    no parameters needed because we use here :func:`~ae.inspector.stack_var` helper function to determine the
+    the module file path via the `__file__` module variable of the caller module in the call stack. in this call
     we have to overwrite the default value (:data:`~ae.inspector.SKIPPED_MODULES`) of the
     :paramref:`~ae.inspector.stack_var.skip_modules` parameter to not skip ae portions that are providing
     package resources and are listed in the :data:`~ae.inspector.SKIPPED_MODULES`, like e.g. :mod:`ae.gui_app` and
@@ -617,8 +617,8 @@ def register_package_images():
 def register_package_sounds():
     """ call from module scope of the package to register/add sound file resources.
 
-    No parameters needed because we use here :func:`~ae.inspector.stack_var` helper function to determine the
-    the module file path via the `__file__` module variable of the caller module in the call stack. In this call
+    no parameters needed because we use here :func:`~ae.inspector.stack_var` helper function to determine the
+    the module file path via the `__file__` module variable of the caller module in the call stack. in this call
     we have to overwrite the default value (:data:`~ae.inspector.SKIPPED_MODULES`) of the
     :paramref:`~ae.inspector.stack_var.skip_modules` parameter to not skip ae portions that are providing
     package resources and are listed in the :data:`~ae.inspector.SKIPPED_MODULES`, like e.g. :mod:`ae.gui_app`
@@ -701,7 +701,7 @@ class MainAppBase(ConsoleApp, ABC):
         self._start_event_loop: Optional[Callable]          #: callable to start event loop of GUI framework
         self._stop_event_loop: Optional[Callable]           #: callable to start event loop of GUI framework
 
-        self.flow_path = list()     # init for Literal type recognition - will be overwritten by setup_app_states()
+        self.flow_path = list()     # init for literal type recognition - will be overwritten by setup_app_states()
 
         add_common_storage_paths()  # determine platform specific path placeholders, like e.g. {pictures}, {downloads}..
 
@@ -816,7 +816,7 @@ class MainAppBase(ConsoleApp, ABC):
         :param event_kwargs:    optional args to pass additional data or info onto and from the flow change confirmation
                                 event handler.
 
-                                The following keys are currently supported/implemented by this module/portion
+                                the following keys are currently supported/implemented by this module/portion
                                 (additional keys can be added by the modules/apps using this method):
 
                                 * `changed_event_name`: optional main app event method name to be called if the flow got
@@ -838,14 +838,14 @@ class MainAppBase(ConsoleApp, ABC):
                                   string value to change the last focus flow id to the passed value.
                                 * `tap_widget`: optional tapped button widget instance (initiating this flow change).
 
-                                Some of these keys get passed directly on the call of this method, e.g. via
+                                some of these keys get passed directly on the call of this method, e.g. via
                                 :attr:`~.kivy_app.FlowButton.tap_kwargs` or :attr:`~.kivy_app.FlowToggler.tap_kwargs`,
                                 where others get added by the flow change confirmation handlers/callbacks.
 
         :return:                True if flow got confirmed by a declared custom flow change confirmation event handler
                                 (either event method or Popup class) of the app and changed accordingly, else False.
 
-                                Some flow actions are handled internally independent from the return value of a
+                                some flow actions are handled internally independent from the return value of a
                                 custom event handler, like e.g. `'enter'` or `'leave'` will always extend or reduce the
                                 flow path and the action `'focus'` will give the indexed widget the input focus (these
                                 exceptions are configurable via :data:`ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION`).
@@ -1088,7 +1088,7 @@ class MainAppBase(ConsoleApp, ABC):
     def load_translations(self, lang_code: str):
         """ load translation texts for the passed language code.
 
-        :param lang_code:       the new language code to be set (passed as flow key). Empty on first app run/start.
+        :param lang_code:       the new language code to be set (passed as flow key). empty on first app run/start.
         """
         is_empty = not lang_code
         old_lang = self.lang_code
@@ -1161,7 +1161,7 @@ class MainAppBase(ConsoleApp, ABC):
                                 will be passed onto the `__init__` method of the found Popup class.
         :return:                True if Popup class was found and displayed.
 
-        This method is mainly used as the last fallback clicked flow change confirmation event handler of a FlowButton.
+        this method is mainly used as the last fallback clicked flow change confirmation event handler of a FlowButton.
         """
         class_name = flow_popup_class_name(flow_id)
         self.vpo(f"MainAppBase.on_flow_change '{flow_id}' {event_kwargs} lookup={class_name}")
@@ -1195,7 +1195,7 @@ class MainAppBase(ConsoleApp, ABC):
     def on_lang_code_change(self, lang_code: str, _event_kwargs: EventKwargsType) -> bool:
         """ language app state change flow change confirmation event handler.
 
-        :param lang_code:       the new language code to be set (passed as flow key). Empty on first app run/start.
+        :param lang_code:       the new language code to be set (passed as flow key). empty on first app run/start.
         :param _event_kwargs:   unused event kwargs.
         :return:                True to confirm the language change.
         """
@@ -1291,7 +1291,7 @@ class MainAppBase(ConsoleApp, ABC):
         :return:                created and displayed/opened popup class instance.
 
         .. hint::
-            Overwrite this method if framework is using different method to open popup window or if
+            overwrite this method if framework is using different method to open popup window or if
             a widget in the Popup/DropDown need to get the input focus.
         """
         self.dpo(f"MainAppBase.open_popup {popup_class} {popup_kwargs}")
@@ -1305,7 +1305,7 @@ class MainAppBase(ConsoleApp, ABC):
         """ determine all popup-like container widgets that are currently opened.
 
         :param classes:         optional class filter - if not passed then only the widgets underneath win/root with an
-                                `open` method will be added. Pass tuple to restrict found popup widgets to certain
+                                `open` method will be added. pass tuple to restrict found popup widgets to certain
                                 classes. like e.g. by passing (Popup, DropDown, FlowPopup) to get all popups of an
                                 ae/Kivy app.
         :return:                list of opened/visible popup class instances that are children of either the
@@ -1498,7 +1498,7 @@ class MainAppBase(ConsoleApp, ABC):
         :param wid:             widget to determine the position of.
         :return:                tuple of x and y screen coordinate.
         """
-        return wid.pos
+        return wid.x, wid.y
 
     def widgets_enclosing_rectangle(self, widgets: Union[list, tuple]) -> Tuple[float, float, float, float]:
         """ calculate the minimum bounding rectangle all the passed widgets.
@@ -1531,7 +1531,7 @@ class MainAppBase(ConsoleApp, ABC):
         :param wid:             widget to determine the size of.
         :return:                tuple of width and height in pixels.
         """
-        return wid.size
+        return wid.width, wid.height
 
     @staticmethod
     def widget_visible(wid: Any) -> bool:
